import { PluginFactoryOptions, Output, Group, ResolveNameParams } from '@kubb/core';
import { HttpMethod } from '@kubb/oas';
import { ResolvePathOptions, Exclude, Include, Override, Generator } from '@kubb/plugin-oas';

type Options$1 = {
    /**
     * Specify the export location for the files and define the behavior of the output
     * @default { path: 'clients', barrelType: 'named' }
     */
    output?: Output;
    /**
     * Group the clients based on the provided name.
     */
    group?: Group;
    /**
     * Array containing exclude parameters to exclude/skip tags/operations/methods/paths.
     */
    exclude?: Array<Exclude>;
    /**
     * Array containing include parameters to include tags/operations/methods/paths.
     */
    include?: Array<Include>;
    /**
     * Array containing override parameters to override `options` based on tags/operations/methods/paths.
     */
    override?: Array<Override<ResolvedOptions$1>>;
    /**
     * Create `operations.ts` file with all operations grouped by methods.
     * @default false
     */
    operations?: boolean;
    /**
     * Path to the client import path that will be used to do the API calls.
     * It will be used as `import client from '${client.importPath}'`.
     * It allows both relative and absolute path but be aware that we will not change the path.
     * @default '@kubb/plugin-client/client'
     */
    importPath?: string;
    /**
     * ReturnType that will be used when calling the client.
     * - 'data' will return ResponseConfig[data].
     * - 'full' will return ResponseConfig.
     * @default 'data'
     */
    dataReturnType?: 'data' | 'full';
    /**
     * How to pass your params
     * - 'object' will return the params and pathParams as an object.
     * - 'inline' will return the params as comma separated params.
     * @default 'inline'
     */
    paramsType?: 'object' | 'inline';
    /**
     * How to pass your pathParams.
     * - 'object' will return the pathParams as an object.
     * - 'inline' will return the pathParams as comma separated params.
     * @default 'inline'
     */
    pathParamsType?: 'object' | 'inline';
    /**
     * Which parser can be used before returning the data
     * - 'zod'  will use `@kubb/plugin-zod` to parse the data.
     * @default 'client'
     */
    parser?: 'client' | 'zod';
    transformers?: {
        /**
         * Customize the names based on the type that is provided by the plugin.
         */
        name?: (name: ResolveNameParams['name'], type?: ResolveNameParams['type']) => string;
    };
    /**
     * Define some generators next to the client generators
     */
    generators?: Array<Generator<PluginClient>>;
};
type ResolvedOptions$1 = {
    output: Output;
    group?: Options$1['group'];
    baseURL: string | undefined;
    parser: NonNullable<Options$1['parser']>;
    importPath: NonNullable<Options$1['importPath']>;
    dataReturnType: NonNullable<Options$1['dataReturnType']>;
    pathParamsType: NonNullable<Options$1['pathParamsType']>;
    paramsType: NonNullable<Options$1['paramsType']>;
};
type PluginClient = PluginFactoryOptions<'plugin-client', Options$1, ResolvedOptions$1, never, ResolvePathOptions>;

type Query = {
    /**
     * Customize the queryKey, here you can specify a suffix.
     */
    key: (key: unknown[]) => unknown[];
    /**
     * Define which HttpMethods can be used for queries
     * @default ['get']
     */
    methods: Array<HttpMethod>;
    /**
     * Path to the useQuery that will be used to do the useQuery functionality.
     * It will be used as `import { useQuery } from '${importPath}'`.
     * It allows both relative and absolute path.
     * the path will be applied as is, so relative path should be based on the file being generated.
     * @default '@tanstack/svelte-query'
     */
    importPath?: string;
};
type Mutation = {
    /**
     * Customize the queryKey, here you can specify a suffix.
     */
    key: (key: unknown[]) => unknown[];
    /**
     * Define which HttpMethods can be used for mutations
     * @default ['post', 'put', 'delete']
     */
    methods: Array<HttpMethod>;
    /**
     * Path to the useQuery that will be used to do the useQuery functionality.
     * It will be used as `import { useQuery } from '${importPath}'`.
     * It allows both relative and absolute path.
     * the path will be applied as is, so relative path should be based on the file being generated.
     * @default '@tanstack/svelte-query'
     */
    importPath?: string;
};
type Options = {
    /**
     * Specify the export location for the files and define the behavior of the output
     * @default { path: 'hooks', barrelType: 'named' }
     */
    output?: Output;
    /**
     * Group the @tanstack/query hooks based on the provided name.
     */
    group?: Group;
    client?: Pick<PluginClient['options'], 'dataReturnType' | 'importPath'>;
    /**
     * Array containing exclude parameters to exclude/skip tags/operations/methods/paths.
     */
    exclude?: Array<Exclude>;
    /**
     * Array containing include parameters to include tags/operations/methods/paths.
     */
    include?: Array<Include>;
    /**
     * Array containing override parameters to override `options` based on tags/operations/methods/paths.
     */
    override?: Array<Override<ResolvedOptions>>;
    /**
     * How to pass your params
     * - 'object' will return the params and pathParams as an object.
     * - 'inline' will return the params as comma separated params.
     * @default 'inline'
     */
    paramsType?: 'object' | 'inline';
    /**
     * How to pass your pathParams.
     * - 'object' will return the pathParams as an object.
     * - 'inline' will return the pathParams as comma separated params.
     * @default 'inline'
     */
    pathParamsType?: PluginClient['options']['pathParamsType'];
    /**
     * Override some useQuery behaviours.
     */
    query?: Partial<Query> | false;
    /**
     * Override some useMutation behaviours.
     */
    mutation?: Mutation | false;
    /**
     * Which parser should be used before returning the data to `@tanstack/query`.
     * `'zod'` will use `@kubb/plugin-zod` to parse the data.
     */
    parser?: PluginClient['options']['parser'];
    transformers?: {
        /**
         * Customize the names based on the type that is provided by the plugin.
         */
        name?: (name: ResolveNameParams['name'], type?: ResolveNameParams['type']) => string;
    };
    /**
     * Define some generators next to the svelte-query generators
     */
    generators?: Array<Generator<PluginSvelteQuery>>;
};
type ResolvedOptions = {
    output: Output;
    baseURL: string | undefined;
    client: Required<NonNullable<PluginSvelteQuery['options']['client']>>;
    parser: Required<NonNullable<Options['parser']>>;
    paramsType: NonNullable<Options['paramsType']>;
    pathParamsType: NonNullable<Options['pathParamsType']>;
    query: NonNullable<Required<Query>> | false;
    mutation: NonNullable<Required<Mutation>> | false;
};
type PluginSvelteQuery = PluginFactoryOptions<'plugin-svelte-query', Options, ResolvedOptions, never, ResolvePathOptions>;

export type { Options as O, PluginSvelteQuery as P };
